package com.ruoyi.system.service.impl;

import com.ruoyi.common.config.Global;
import com.ruoyi.common.core.text.Convert;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.QyCzrxx;
import com.ruoyi.system.mapper.QyCzrxxMapper;
import com.ruoyi.system.service.IQyCzrxxService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;
import java.util.UUID;

import static com.ruoyi.common.utils.ImgUtils.Base64ToImage;

/**
 * 出资人信息表Service业务层处理
 *
 * @author ruoyi
 * @date 2019-09-10
 */
@Service
public class QyCzrxxServiceImpl implements IQyCzrxxService
{
    @Autowired
    private QyCzrxxMapper qyCzrxxMapper;

    /**
     * 查询出资人信息表
     *
     * @param id 出资人信息表ID
     * @return 出资人信息表
     */
    @Override
    public QyCzrxx selectQyCzrxxById(Long id)
    {
        return qyCzrxxMapper.selectQyCzrxxById(id);
    }


    /**
     * 查询出资人信息表
     *
     * @return 出资人信息表
     */
    @Override
    public List<QyCzrxx>  selectQyCzrxxByBsid(String bsid)
    {
        return qyCzrxxMapper.selectQyCzrxxByBsid(bsid);
    }

    /**
     * 查询出资人信息表列表
     *
     * @param qyCzrxx 出资人信息表
     * @return 出资人信息表
     */
    @Override
    public List<QyCzrxx> selectQyCzrxxList(QyCzrxx qyCzrxx)
    {
        return qyCzrxxMapper.selectQyCzrxxList(qyCzrxx);
    }

    /**
     * 新增出资人信息表
     *
     * @param qyCzrxx 出资人信息表
     * @return 结果
     */
    @Override
    public int insertQyCzrxx(QyCzrxx qyCzrxx)
    {
        return qyCzrxxMapper.insertQyCzrxx(qyCzrxx);
    }

    /**
     * 修改出资人信息表
     *
     * @param qyCzrxx 出资人信息表
     * @return 结果
     */
    @Override
    public int updateQyCzrxx(QyCzrxx qyCzrxx)
    {
        return qyCzrxxMapper.updateQyCzrxx(qyCzrxx);
    }

    /**
     * 删除出资人信息表对象
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteQyCzrxxByIds(String ids)
    {
        return qyCzrxxMapper.deleteQyCzrxxByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除出资人信息表信息
     *
     * @param id 出资人信息表ID
     * @return 结果
     */
    public int deleteQyCzrxxById(Long id)
    {
        return qyCzrxxMapper.deleteQyCzrxxById(id);
    }
    /**
     * 新增出资人信息表
     *
     * @param  request 出资人信息表
     * @return 结果
     */
    @Override
    public int insertQyCzr(HttpServletRequest request)
    {
        QyCzrxx czr= new QyCzrxx();
        String bsid = request.getParameter("bsid");//唯一标识码
        czr.setBsid(bsid);
        String czfs = request.getParameter("czfs");// 出资方式
        czr.setCzfs(czfs);
        if(czfs==""||czfs==null){
            czr.setCzfs("货币");
        }


        String czrtype = request.getParameter("rentype");//出资人类型
        czr.setCzrtype(czrtype);
        String czrname = request.getParameter("renname");//出资人名称
        czr.setCzrname(czrname);
        String czrphone = request.getParameter("renmoblie");//出资人电话
        czr.setCzrphone(czrphone);
        String czrlx = request.getParameter("renphone");//出资人联系
        czr.setCzrlx(czrlx);
        String czrzj = request.getParameter("cze");//出资人资金
        czr.setCzrzj(czrzj);
        czr.setRenjiaoje(czrzj);
        String czrcardno = request.getParameter("rencardno");//出资人身份证
        czr.setCzrcardno(czrcardno);
        String czrxb = request.getParameter("rensex");//出资人性别
        czr.setCzrxb(czrxb);
        String czrzz = request.getParameter("renaddress");//出资人住址
        czr.setCzrzz(czrzz);
        String czrdzyx = request.getParameter("renemail");//出资人地址邮箱
        czr.setCzrdzyx(czrdzyx);

        //出资人身份证
        String czrsfz= "/QySqImg/"+ DateUtils.datePaths()+"/" + UUID.randomUUID().toString().replaceAll("-","").toLowerCase()+".jpg";
        if(Base64ToImage(request.getParameter("czrsfz"), Global.getProfile()+czrsfz)){
            czr.setCzrsfz("/profile"+czrsfz);
        }
        //出资人身份证1
        String czrsfz1= "/QySqImg/"+ DateUtils.datePaths()+"/" + UUID.randomUUID().toString().replaceAll("-","").toLowerCase()+".jpg";
        if(Base64ToImage(request.getParameter("czrsfz1"), Global.getProfile()+czrsfz1)){
            czr.setCzrsfz1("/profile"+czrsfz1);
        }
        //出资人签名
        String czrqm= "/QySqImg/"+ DateUtils.datePaths()+"/" + UUID.randomUUID().toString().replaceAll("-","").toLowerCase()+".jpg";
        if(Base64ToImage(request.getParameter("renqianming"), Global.getProfile()+czrqm)){
            czr.setCzrqm("/profile"+czrqm);
        }
        //出资人拍照
        String czrpaizhao= "/QySqImg/"+ DateUtils.datePaths()+"/" + UUID.randomUUID().toString().replaceAll("-","").toLowerCase()+".jpg";
        if(Base64ToImage(request.getParameter("renphoto"), Global.getProfile()+czrpaizhao)){
            czr.setCzrpaizhao("/profile"+czrpaizhao);
        }

        DateFormat format1 = new SimpleDateFormat("yyyy-MM-dd");
        DateFormat format2= new SimpleDateFormat("yyyy年MM月dd日 HH时mm分ss秒");
        Date date = null;
        String sdate= request.getParameter("nian")+"-"+request.getParameter("yue")+"-"+request.getParameter("ri");
        try {
            date = format1.parse(sdate);
//            date = format2.parse(sdate);
            System.err.println(date);
            czr.setRenjiaoqxtime(date);
        } catch (java.text.ParseException e) {
            e.printStackTrace();
        }
        czr.setShijiaoqxtime(date);//实缴日期
        return qyCzrxxMapper.insertQyCzrxx(czr);
    }
}
